# Changelog

All notable changes to this project will be documented in this file

## 0.1.1 - 2024-10-21

### Fixed

- Fixed example directive sometimes not updating `uses` values

### Changed

- Changed YAML library to ruamel in order to preserve formatting


## 0.1.0 - 2024-10-20

Initial release